Improve this doc

# Error: $compile:iscp
Invalid Isolate Scope Definition

    Invalid isolate scope definition for directive '{0}'. Definition: {... {1}: '{2}' ...}

## Description

When declaring isolate scope the scope definition object must be in specific format which starts with mode character (`@&=`) with an optional local name.

    myModule.directive('directiveName', function factory() {
      return {
        ...
        scope: {
          'attrName': '@', // OK
          'attrName2': '=localName', // OK
          'attrName3': 'name',    // ERROR: missing mode @&=
          'attrName4': ' = name', // ERROR: extra spaces
          'attrName5': 'name=',   // ERROR: must be prefixed with @&=
        }
        ...
      }
    });

Please refer to the `scope` option of the directive definition documentation to learn more about the API.